@@ -2,7 +2,17 @@
 
 # construct_dt_and_classify_one_sample_case2.pl
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
+
+
+##  This script is for a mixture of symbolic and numeric features.  Since
+##  we have numeric features, only a csv file can be used for training.
+##  Note how we tell the module that the class label in each training
+##  record is placed in the column indexed 2 and how the feature are to be
+##  found in columns indexed 3, 4, 5, 6, 7, and 8.
+
+##  Remember, the column indexing in the csv file is zero-based.  That is,
+##  the first column is indexed 0.
 
 use strict;
 use Algorithm::DecisionTree;
