@@ -1,5 +1,7 @@
 #!/usr/bin/perl -w
 
+use lib '../blib/lib', '../blib/arch';
+
 # construct_dt_for_heavytailed.pl
 
 ##  This script illustrates how to set up your DecisionTree
@@ -7,9 +9,6 @@
 ##  training file has a large dynamic range and is likely to
 ##  be heavytailed.
 
-
-#use lib '../blib/lib', '../blib/arch';
-
 use strict;
 use Algorithm::DecisionTree;
 
